Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1386)

Unified Diff: src/profile-generator.cc

Issue 1631018: Only put VM state entry if a symbolized stacktrace is empty. (Closed)
Patch Set: Comments addressed Created 10 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/profile-generator.cc
diff --git a/src/profile-generator.cc b/src/profile-generator.cc
index a842eb2fef5bef6b9ae61e3f12217fd6a4db0ac8..4c2a330898145beadb4d226657fe52ac62516eaa 100644
--- a/src/profile-generator.cc
+++ b/src/profile-generator.cc
@@ -562,8 +562,17 @@ void ProfileGenerator::RecordTickSample(const TickSample& sample) {
}
if (FLAG_prof_browser_mode) {
- // Put VM state as the topmost entry.
- *entry++ = EntryForVMState(sample.state);
+ bool no_symbolized_entries = true;
+ for (CodeEntry** e = entries.start(); e != entry; ++e) {
+ if (*e != NULL) {
+ no_symbolized_entries = false;
+ break;
+ }
+ }
+ // If no frames were symbolized, put the VM state entry in.
+ if (no_symbolized_entries) {
+ *entry++ = EntryForVMState(sample.state);
+ }
}
profiles_->AddPathToCurrentProfiles(entries);
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698